@@ -1,6 +1,4 @@
 package App::Rad::Config;
-use strict;
-use warnings;
 
 sub load_config {
     my ($c, @files) = (@_);
@@ -21,7 +19,7 @@ sub load_config {
             if ( m/^([^\=\:\s]+)        # key
                 (?:                     # (value is optional)
                    (?:\s*[\=\:]\s*|\s+) # separator ('=', ':' or whitespace)
-                   (.+)                 # value
+                   ([^\=\:\s]+)         # value
                 )?
                 /x
             ) {
